==> apache-nuttx-10.2.0-incubating.tar.gz: nuttx/arch/sim/include/types.h <==
/****************************************************************************
 * arch/sim/include/types.h
 *
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.  The
 * ASF licenses this file to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the
 * License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the
 * License for the specific language governing permissions and limitations
 * under the License.
 *
 ****************************************************************************/

/* This file should never be included directly but, rather,
 * only indirectly through sys/types.h
 */

#ifndef __ARCH_SIM_INCLUDE_TYPES_H
#define __ARCH_SIM_INCLUDE_TYPES_H

/****************************************************************************
 * Included Files
 ****************************************************************************/

/****************************************************************************
 * Pre-processor Definitions
 ****************************************************************************/

/****************************************************************************
 * Type Declarations
 ****************************************************************************/

#ifndef __ASSEMBLY__

/* These are the sizes of the standard integer types.  NOTE that these type
 * names have a leading underscore character.  This file will be included
 * (indirectly) by include/stdint.h and typedef'ed to the final name without
 * the underscore character.  This roundabout way of doings things allows
 * the stdint.h to be removed from the include/ directory in the event that
 * the user prefers to use the definitions provided by their toolchain header
 * files
 */

typedef signed char        _int8_t;
typedef unsigned char      _uint8_t;

typedef signed short       _int16_t;
typedef unsigned short     _uint16_t;

typedef signed int         _int32_t;
typedef unsigned int       _uint32_t;

/* Note about host OS types:
 * - int64_t is long long for 64-bit macOS
 * - int64_t is long for Ubuntu x86-64
 *
 * Note for sim/macOS modules:
 * For sim/macOS, usually x86_64-elf-gcc from homebrew is used
 * as MODULECC. It seems to be configured as __INT64_TYPE__ == long int.
 * The __APPLE_CC__ check below is to workaround it.
 * (The host cc defines __APPLE_CC__, while x86_64-elf-gcc doesn't.)
 * XXX It is a problem if you need C++ symbols in symtabs for modules.
 */

#if defined(__APPLE_CC__) || !defined(_LP64)
typedef signed long long   _int64_t;
typedef unsigned long long _uint64_t;
#else
typedef signed long        _int64_t;
typedef unsigned long      _uint64_t;
#endif
#define __INT64_DEFINED

#if defined(__APPLE_CC__)
typedef signed long        _intmax_t;
typedef unsigned long      _uintmax_t;
#else
typedef _int64_t           _intmax_t;
typedef _uint64_t          _uintmax_t;
#endif

#if defined(CONFIG_HOST_X86_64) && !defined(CONFIG_SIM_M32)
/* 64-bit build on 64-bit machine: A size is 8 bytes */

#if defined(__SIZE_TYPE__)
/* If __SIZE_TYPE__ is defined we define ssize_t based on size_t.
 * We simply change "unsigned" to "signed" for this single definition
 * to make sure ssize_t and size_t only differ by their signedness.
 */

#define unsigned signed
typedef __SIZE_TYPE__      _ssize_t;
#undef unsigned
typedef __SIZE_TYPE__      _size_t;
#else
typedef signed long long   _ssize_t;
typedef unsigned long long _size_t;
#endif

#else
/* 32-bit build on 32- or 64-bit machine: A size is 4 bytes */

#if defined(__SIZE_TYPE__)
/* If __SIZE_TYPE__ is defined we define ssize_t based on size_t.
 * We simply change "unsigned" to "signed" for this single definition
 * to make sure ssize_t and size_t only differ by their signedness.
 */

#define unsigned signed
typedef __SIZE_TYPE__      _ssize_t;
#undef unsigned
typedef __SIZE_TYPE__      _size_t;
#elif defined(CONFIG_ARCH_SIZET_LONG)
typedef signed long        _ssize_t;
typedef unsigned long      _size_t;
#else
typedef signed int         _ssize_t;
typedef unsigned int       _size_t;
#endif

#endif

/* This is the size of the interrupt state save returned by
 * up_irq_save()
 */

typedef _uint64_t          irqstate_t;

#endif /* __ASSEMBLY__ */

/****************************************************************************
 * Public Function Prototypes
 ****************************************************************************/

#endif /* __ARCH_SIM_INCLUDE_TYPES_H */

==> apache-nuttx-10.3.0-incubating.tar.gz: nuttx/arch/sim/include/types.h <==
/****************************************************************************
 * arch/sim/include/types.h
 *
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.  The
 * ASF licenses this file to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the
 * License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the
 * License for the specific language governing permissions and limitations
 * under the License.
 *
 ****************************************************************************/

/* This file should never be included directly but, rather,
 * only indirectly through sys/types.h
 */

#ifndef __ARCH_SIM_INCLUDE_TYPES_H
#define __ARCH_SIM_INCLUDE_TYPES_H

/****************************************************************************
 * Included Files
 ****************************************************************************/

/****************************************************************************
 * Pre-processor Definitions
 ****************************************************************************/

/****************************************************************************
 * Type Declarations
 ****************************************************************************/

#ifndef __ASSEMBLY__

/* These are the sizes of the standard integer types.  NOTE that these type
 * names have a leading underscore character.  This file will be included
 * (indirectly) by include/stdint.h and typedef'ed to the final name without
 * the underscore character.  This roundabout way of doings things allows
 * the stdint.h to be removed from the include/ directory in the event that
 * the user prefers to use the definitions provided by their toolchain header
 * files
 */

typedef signed char        _int8_t;
typedef unsigned char      _uint8_t;

typedef signed short       _int16_t;
typedef unsigned short     _uint16_t;

typedef signed int         _int32_t;
typedef unsigned int       _uint32_t;

/* Note about host OS types:
 * - int64_t is long long for 64-bit macOS
 * - int64_t is long for Ubuntu x86-64
 *
 * Note for sim/macOS modules:
 * For sim/macOS, usually x86_64-elf-gcc from homebrew is used
 * as MODULECC. It seems to be configured as __INT64_TYPE__ == long int.
 * The __APPLE_CC__ check below is to workaround it.
 * (The host cc defines __APPLE_CC__, while x86_64-elf-gcc doesn't.)
 * XXX It is a problem if you need C++ symbols in symtabs for modules.
 */

#if defined(__APPLE_CC__) || !defined(_LP64)
typedef signed long long   _int64_t;
typedef unsigned long long _uint64_t;
#else
typedef signed long        _int64_t;
typedef unsigned long      _uint64_t;
#endif
#define __INT64_DEFINED

#if defined(__APPLE_CC__)
typedef signed long        _intmax_t;
typedef unsigned long      _uintmax_t;
#else
typedef _int64_t           _intmax_t;
typedef _uint64_t          _uintmax_t;
#endif

#if defined(__WCHAR_TYPE__)
typedef __WCHAR_TYPE__     _wchar_t;
#else
typedef int                _wchar_t;
#endif

#if defined(__SIZE_TYPE__)
/* If __SIZE_TYPE__ is defined we define ssize_t based on size_t.
 * We simply change "unsigned" to "signed" for this single definition
 * to make sure ssize_t and size_t only differ by their signedness.
 */

#define unsigned signed
typedef __SIZE_TYPE__      _ssize_t;
#undef unsigned
typedef __SIZE_TYPE__      _size_t;
#elif defined(CONFIG_ARCH_SIZET_LONG)
typedef signed long        _ssize_t;
typedef unsigned long      _size_t;
#else
typedef signed int         _ssize_t;
typedef unsigned int       _size_t;
#endif

/* This is the size of the interrupt state save returned by
 * up_irq_save()
 */

typedef _uint64_t          irqstate_t;

#endif /* __ASSEMBLY__ */

/****************************************************************************
 * Public Function Prototypes
 ****************************************************************************/

#endif /* __ARCH_SIM_INCLUDE_TYPES_H */
